@@ -1,5 +1,5 @@
 #
-# $Date: 2006/05/03 22:12:56 $
+# $Date: 2007/12/21 18:05:15 $
 #
 # Data / Content layer functions
 #
@@ -710,7 +710,7 @@ sub report {
     }    # not dls
 
     Exec::exec_pipe(*OUT,
-"'$::TSKDIR/dcat' -f $ftype $usize_str  -o $offset -i $imgtype $img $block $len | '$::TSKDIR/md5'"
+"'$::TSKDIR/dcat' -f $ftype $usize_str  -o $offset -i $imgtype $img $block $len | '$::MD5_EXE'"
     );
     my $md5 = Exec::read_pipe_line(*OUT);
     close(OUT);
@@ -723,17 +723,17 @@ sub report {
 
     if ($sort == $Data::SORT_HEX) {
         Exec::exec_pipe(*OUT,
-"'$::TSKDIR/dcat' -f $ftype $usize_str -h  -o $offset -i $imgtype $img $block $len | '$::TSKDIR/md5'"
+"'$::TSKDIR/dcat' -f $ftype $usize_str -h  -o $offset -i $imgtype $img $block $len | '$::MD5_EXE'"
         );
     }
     elsif ($sort == $Data::SORT_ASC) {
         Exec::exec_pipe(*OUT,
-"'$::TSKDIR/dcat' -f $ftype $usize_str -a  -o $offset -i $imgtype $img $block $len | '$::TSKDIR/md5'"
+"'$::TSKDIR/dcat' -f $ftype $usize_str -a  -o $offset -i $imgtype $img $block $len | '$::MD5_EXE'"
         );
     }
     elsif ($sort == $Data::SORT_STR) {
         Exec::exec_pipe(*OUT,
-"'$::TSKDIR/dcat' -f $ftype $usize_str  -o $offset -i $imgtype $img $block $len | '$::TSKDIR/srch_strings' -a | '$::TSKDIR/md5'"
+"'$::TSKDIR/dcat' -f $ftype $usize_str  -o $offset -i $imgtype $img $block $len | '$::TSKDIR/srch_strings' -a | '$::MD5_EXE'"
         );
     }
 
