@@ -1,5 +1,5 @@
 #
-# $Date: 2006/05/08 18:46:57 $
+# $Date: 2007/12/21 18:05:16 $
 #
 # File name layer functions
 #
@@ -2141,7 +2141,7 @@ sub report {
     # Calculate the MD5 value
     local *OUT;
     Exec::exec_pipe(*OUT,
-"'$::TSKDIR/icat' -f $ftype $recflag -o $offset -i $imgtype $img $meta | '$::TSKDIR/md5'"
+"'$::TSKDIR/icat' -f $ftype $recflag -o $offset -i $imgtype $img $meta | '$::MD5_EXE'"
     );
     my $md5 = Exec::read_pipe_line(*OUT);
     close(OUT);
@@ -2157,26 +2157,28 @@ sub report {
         print "MD5 of recovered file: $md5\n";
     }
 
-    Exec::exec_pipe(*OUT,
-"'$::TSKDIR/icat' -f $ftype $recflag -o $offset -i $imgtype $img $meta | '$::TSKDIR/sha1'"
-    );
-    my $sha1 = Exec::read_pipe_line(*OUT);
-    close(OUT);
+    if ($::SHA1_EXE ne "") {
+        Exec::exec_pipe(*OUT,
+    "'$::TSKDIR/icat' -f $ftype $recflag -o $offset -i $imgtype $img $meta | '$::SHA1_EXE'"
+        );
+        my $sha1 = Exec::read_pipe_line(*OUT);
+        close(OUT);
 
-    $sha1 = "Error getting SHA-1 Value"
-      if ((!defined $sha1) || ($sha1 eq ""));
+        $sha1 = "Error getting SHA-1 Value"
+          if ((!defined $sha1) || ($sha1 eq ""));
 
-    chomp $sha1;
-    if ($recflag eq "") {
-        print "SHA-1 of file: $sha1\n";
-    }
-    else {
-        print "SHA-1 of recovered file: $sha1\n";
+        chomp $sha1;
+        if ($recflag eq "") {
+            print "SHA-1 of file: $sha1\n";
+        }
+        else {
+            print "SHA-1 of recovered file: $sha1\n";
+        }
     }
 
     if ($sort == $FIL_SORT_STR) {
         Exec::exec_pipe(*OUT,
-"'$::TSKDIR/icat' -f $ftype $recflag -o $offset -i $imgtype $img $meta | '$::TSKDIR/srch_strings' -a | '$::TSKDIR/md5'"
+"'$::TSKDIR/icat' -f $ftype $recflag -o $offset -i $imgtype $img $meta | '$::TSKDIR/srch_strings' -a | '$::MD5_EXE'"
         );
         $md5 = Exec::read_pipe_line(*OUT);
         close(OUT);
@@ -2187,17 +2189,19 @@ sub report {
         chomp $md5;
         print "MD5 of ASCII strings: $md5\n";
 
-        Exec::exec_pipe(*OUT,
-"'$::TSKDIR/icat' -f $ftype $recflag -o $offset -i $imgtype $img $meta | '$::TSKDIR/srch_strings' -a | '$::TSKDIR/sha1'"
-        );
-        $sha1 = Exec::read_pipe_line(*OUT);
-        close(OUT);
+        if ($::SHA1_EXE ne "") {
+            Exec::exec_pipe(*OUT,
+    "'$::TSKDIR/icat' -f $ftype $recflag -o $offset -i $imgtype $img $meta | '$::TSKDIR/srch_strings' -a | '$::SHA1_EXE'"
+            );
+            $sha1 = Exec::read_pipe_line(*OUT);
+            close(OUT);
 
-        $sha1 = "Error getting SHA-1 Value"
-          if ((!defined $sha1) || ($sha1 eq ""));
+            $sha1 = "Error getting SHA-1 Value"
+              if ((!defined $sha1) || ($sha1 eq ""));
 
-        chomp $sha1;
-        print "SHA-1 of ASCII strings: $sha1\n";
+            chomp $sha1;
+            print "SHA-1 of ASCII strings: $sha1\n";
+        }
     }
 
     print "\nImage: $Caseman::vol2path{$vol}\n";
@@ -2327,7 +2331,7 @@ sub md5list {
 
             local *OUT_MD5;
             Exec::exec_pipe(*OUT_MD5,
-"'$::TSKDIR/icat' -f $ftype -r -o $offset -i $imgtype $img $in | '$::TSKDIR/md5'"
+"'$::TSKDIR/icat' -f $ftype -r -o $offset -i $imgtype $img $in | '$::MD5_EXE'"
             );
             my $md5out = Exec::read_pipe_line(*OUT_MD5);
 
