@@ -1,5 +1,5 @@
 #
-# $Date: 2005/03/06 16:51:02 $
+# $Date: 2006/05/08 18:46:57 $
 #
 package Fs;
 
@@ -7,14 +7,15 @@ $Fs::types[0]  = "ext";
 $Fs::types[1]  = "fat";
 $Fs::types[2]  = "ntfs";
 $Fs::types[3]  = "ufs";
-$Fs::types[4]  = "-----";
-$Fs::types[5]  = "fat12";
-$Fs::types[6]  = "fat16";
-$Fs::types[7]  = "fat32";
-$Fs::types[8]  = "bsdi";
-$Fs::types[9]  = "freebsd";
-$Fs::types[10] = "openbsd";
-$Fs::types[11] = "solaris";
+$Fs::types[4]  = "iso9660";
+$Fs::types[5]  = "-----";
+$Fs::types[6]  = "fat12";
+$Fs::types[7]  = "fat16";
+$Fs::types[8]  = "fat32";
+$Fs::types[9]  = "bsdi";
+$Fs::types[10] = "freebsd";
+$Fs::types[11] = "openbsd";
+$Fs::types[12] = "solaris";
 
 # These need to be updated as The Sleuth Kit supports more file systems
 #
@@ -137,3 +138,12 @@ $Fs::ctime_str{'ntfs'}  = "Changed";
 $Fs::mtime_str{'ntfs'}  = "Written";
 $Fs::meta_str{'ntfs'}   = "MFT Entry";
 $Fs::is_fs{'ntfs'}      = 1;
+
+# ISO9660
+$Fs::first_meta{'iso9660'} = $Fs::root_meta{'iso9660'} = 0;
+$Fs::first_addr{'iso9660'} = 0;
+$Fs::addr_unit{'iso9660'}  = 'Block';
+$Fs::ctime_str{'iso9660'}  = "Changed";
+$Fs::mtime_str{'iso9660'}  = "Modified";
+$Fs::meta_str{'iso9660'}   = "Directory Entry";
+$Fs::is_fs{'iso9660'}      = 1;
