@@ -1,10 +1,10 @@
 #
-# $Date: 2006/05/08 18:46:57 $
+# $Date: 2008/01/30 03:28:09 $
 #
 # Hash database and calculation functions
 #
 # Brian Carrier [carrier@sleuthkit.org]
-# Copyright (c) 2001-2005 by Brian Carrier.  All rights reserved
+# Copyright (c) 2001-2008 by Brian Carrier.  All rights reserved
 #
 # This file is part of the Autopsy Forensic Browser (Autopsy)
 #
@@ -238,9 +238,8 @@ EOF2
 </center>
 <p><b>Overview</b><br>
 These files are known to be <U>good</U> and <U>bad</U>.  It is currently
-difficult to distinguish between known good and known bad and therefore
-the NSRL is no longer used much in Autopsy until a better solution can
-be found.
+difficult to distinguish between known good and known bad, but the NSRL
+is used in Autopsy to ignore all known files.
 
 EOF3
 
@@ -760,7 +759,7 @@ sub calc_md5 {
 
     alarm(5);
     local *OUT;
-    Exec::exec_pipe(*OUT, "'$::TSKDIR/md5' $img");
+    Exec::exec_pipe(*OUT, "'$::MD5_EXE' $img");
 
     alarm(0);
     $SIG{ALRM} = 'DEFAULT';
@@ -803,7 +802,7 @@ sub calc_md5_split {
     local *OUT;
 
     # We use the dls method so that we can handle split images
-    Exec::exec_pipe(*OUT, "'$::TSKDIR/dls' -f raw -e $img | '$::TSKDIR/md5'");
+    Exec::exec_pipe(*OUT, "'$::TSKDIR/dls' -f raw -e $img | '$::MD5_EXE'");
 
     alarm(0);
     $SIG{ALRM} = 'DEFAULT';
