@@ -1,5 +1,5 @@
 #
-# $Date: 2006/05/03 22:12:57 $
+# $Date: 2007/12/21 18:05:17 $
 #
 # Metadata mode
 #
@@ -313,12 +313,12 @@ sub stats {
     # MD5 Value
     if ($recmode == $File::REC_YES) {
         Exec::exec_pipe(*OUT,
-"'$::TSKDIR/icat' -f $ftype -r -o $offset -i $imgtype $img $meta | '$::TSKDIR/md5'"
+"'$::TSKDIR/icat' -f $ftype -r -o $offset -i $imgtype $img $meta | '$::MD5_EXE'"
         );
     }
     else {
         Exec::exec_pipe(*OUT,
-"'$::TSKDIR/icat' -f $ftype -o $offset -i $imgtype $img $meta | '$::TSKDIR/md5'"
+"'$::TSKDIR/icat' -f $ftype -o $offset -i $imgtype $img $meta | '$::MD5_EXE'"
         );
     }
 
@@ -376,30 +376,32 @@ sub stats {
     }
 
     # SHA-1 Value
-    if ($recmode == $File::REC_YES) {
-        Exec::exec_pipe(*OUT,
-"'$::TSKDIR/icat' -f $ftype -r -o $offset -i $imgtype $img $meta | '$::TSKDIR/sha1'"
-        );
-    }
-    else {
-        Exec::exec_pipe(*OUT,
-"'$::TSKDIR/icat' -f $ftype -o $offset -i $imgtype $img $meta | '$::TSKDIR/sha1'"
-        );
-    }
+    if ($::SHA1_EXE ne "") {
+        if ($recmode == $File::REC_YES) {
+            Exec::exec_pipe(*OUT,
+    "'$::TSKDIR/icat' -f $ftype -r -o $offset -i $imgtype $img $meta | '$::SHA1_EXE'"
+            );
+        }
+        else {
+            Exec::exec_pipe(*OUT,
+    "'$::TSKDIR/icat' -f $ftype -o $offset -i $imgtype $img $meta | '$::SHA1_EXE'"
+            );
+        }
 
-    my $sha1out = Exec::read_pipe_line(*OUT);
-    close(OUT);
+        my $sha1out = Exec::read_pipe_line(*OUT);
+        close(OUT);
 
-    $sha1out = "Error getting SHA-1"
-      if ((!defined $sha1out) || ($sha1out eq ""));
+        $sha1out = "Error getting SHA-1"
+          if ((!defined $sha1out) || ($sha1out eq ""));
 
-    chomp $sha1out;
-    if ($recmode == $File::REC_YES) {
-        print
-          "<b>SHA-1 of recovered content:</b><br><tt>$sha1out</tt><br><br>\n";
-    }
-    else {
-        print "<b>SHA-1 of content:</b><br><tt>$sha1out</tt><br><br>\n";
+        chomp $sha1out;
+        if ($recmode == $File::REC_YES) {
+            print
+              "<b>SHA-1 of recovered content:</b><br><tt>$sha1out</tt><br><br>\n";
+        }
+        else {
+            print "<b>SHA-1 of content:</b><br><tt>$sha1out</tt><br><br>\n";
+        }
     }
 
     # istat output
@@ -601,7 +603,7 @@ sub report {
     close(OUT);
 
     Exec::exec_pipe(*OUT,
-"'$::TSKDIR/istat' -f $ftype $tz -s $Caseman::ts -o $offset -i $imgtype $img $meta | '$::TSKDIR/md5'"
+"'$::TSKDIR/istat' -f $ftype $tz -s $Caseman::ts -o $offset -i $imgtype $img $meta | '$::MD5_EXE'"
     );
     my $md5 = Exec::read_pipe_line(*OUT);
     close(OUT);
@@ -612,17 +614,19 @@ sub report {
     chop $md5;
     print "MD5 of istat output: $md5\n";
 
-    Exec::exec_pipe(*OUT,
-"'$::TSKDIR/istat' -f $ftype $tz -s $Caseman::ts -o $offset -i $imgtype $img $meta | '$::TSKDIR/sha1'"
-    );
-    my $sha1 = Exec::read_pipe_line(*OUT);
-    close(OUT);
+    if ($::SHA1_EXE ne "") {
+        Exec::exec_pipe(*OUT,
+    "'$::TSKDIR/istat' -f $ftype $tz -s $Caseman::ts -o $offset -i $imgtype $img $meta | '$::SHA1_EXE'"
+        );
+        my $sha1 = Exec::read_pipe_line(*OUT);
+        close(OUT);
 
-    $sha1 = "Error getting SHA-1 Value"
-      if ((!defined $sha1) || ($sha1 eq ""));
+        $sha1 = "Error getting SHA-1 Value"
+          if ((!defined $sha1) || ($sha1 eq ""));
 
-    chop $sha1;
-    print "SHA-1 of istat output: $sha1\n";
+        chop $sha1;
+        print "SHA-1 of istat output: $sha1\n";
+    }
 
     print "\nImage: $Caseman::vol2path{$vol}\n";
     if (($Caseman::vol2start{$vol} == 0) && ($Caseman::vol2end{$vol} == 0)) {
