@@ -1,5 +1,5 @@
 #
-# $Date: 2006/05/03 22:12:57 $
+# $Date: 2007/04/19 21:25:17 $
 #
 # Notes and sequencer functions
 #
@@ -146,7 +146,7 @@ sub enter_file {
     $meta_int = $1 if ($meta_int =~ /^(\d+)-\d+(-\d+)?$/);
     local *OUT;
     Exec::exec_pipe(*OUT,
-        "'$::TSKDIR/ils' -f $ftype -e  -o $offset -i $imgtype $img $meta_int");
+        "'$::TSKDIR/ils' -s $Caseman::ts -f $ftype -e  -o $offset -i $imgtype $img $meta_int");
 
     # Get the fourth line
     my $tmp = Exec::read_pipe_line(*OUT);
@@ -323,7 +323,7 @@ sub write_file {
     $meta_int = $1 if ($meta_int =~ /^(\d+)-\d+(-\d+)?$/);
     local *OUT;
     Exec::exec_pipe(*OUT,
-        "'$::TSKDIR/ils' -f $ftype -e -o $offset -i $imgtype $img $meta_int");
+        "'$::TSKDIR/ils' -s $Caseman::ts -f $ftype -e -o $offset -i $imgtype $img $meta_int");
 
     # Skip to the fourth line
     my $tmp = Exec::read_pipe_line(*OUT);
